import {Injectable} from '@angular/core';
import {HttpClient, HttpResponse} from '@angular/common/http';
import {Observable} from 'rxjs';
import {environment} from '../../environments/environment';


@Injectable()
export class BackendService {

    constructor(private httpClient: HttpClient) {}

    public getTasks(): Observable<HttpResponse<ScrumTask[]>> {
        const url = `${environment.apiUrl}/tasks`;
        return this.httpClient.get<ScrumTask[]>(url, { observe: 'response' });
    }

    public getTask(id: number): Observable<HttpResponse<ScrumTask>> {
        const url = `${environment.apiUrl}/tasks/${id}`;
        return this.httpClient.get<ScrumTask>(url, { observe: 'response' });
    }

    public postTask(task: ScrumTask): Observable<HttpResponse<ScrumTask>> {
        const url = `${environment.apiUrl}/tasks`;
        return this.httpClient.post<ScrumTask>(url, task, { observe: 'response' });
    }

    public putTask(task: ScrumTask): Observable<HttpResponse<any>> {
        const url = `${environment.apiUrl}/tasks/${task.id}`;
        return this.httpClient.put(url, task, { observe: 'response' });
    }

    public deleteTask(task: ScrumTask): Observable<HttpResponse<any>> {
        const url = `${environment.apiUrl}/tasks/${task.id}`;
        return this.httpClient.delete(url, {observe: 'response'});
    }




    public getUserstories(): Observable<HttpResponse<ScrumUserstory[]>> {
        const url = `${environment.apiUrl}/userstories`;
        return this.httpClient.get<ScrumUserstory[]>(url, { observe: 'response' });
    }

    public getUserstory(id: number): Observable<HttpResponse<ScrumUserstory>> {
        const url = `${environment.apiUrl}/userstories/${id}`;
        return this.httpClient.get<ScrumUserstory>(url, { observe: 'response' });
    }

    public postUserstory(userstory: ScrumUserstory): Observable<HttpResponse<ScrumUserstory>> {
        const url = `${environment.apiUrl}/userstories`;
        return this.httpClient.post<ScrumUserstory>(url, userstory, { observe: 'response' });
    }

    public putUserstory(userstory: ScrumUserstory): Observable<HttpResponse<any>> {
        const url = `${environment.apiUrl}/userstories/${userstory.id}`;
        return this.httpClient.put(url, userstory, { observe: 'response' });
    }

    public deleteUserstory(userstory: ScrumUserstory): Observable<HttpResponse<any>> {
        const url = `${environment.apiUrl}/userstories/${userstory.id}`;
        return this.httpClient.delete(url, {observe: 'response'});
    }

}

export enum Priority {
    High="high",
    Medium="medium",
    Low="low"
}

export interface ScrumTask {
    id?: number;
    title: string;
    content?: string;
    status?: number;
    category?: number;
    assignedto?: number;
    sprint?: number;
    project?: number;
    userstory?: number;
    priority?: Priority;
}

export interface ScrumUserstory {
    id?: number;
    title: string;
    content?: string;
    priority?: Priority;
    status?: number;
    category?: number;
    createdby?: number;
    project?: number;
}

export interface ScrumSprint{
    id?: number;
    title: string;
    description: string;
    startDate: Date;
    endDate: Date;
    project: number;
}

export interface ScrumCategory {
    id?: number;
    title: string;
    description?: string;
    color?: string;
    project: number;
}

export interface ScrumStatus {
    id? : number;
    title: string;
    description: string;
}


export interface ScrumUser {
    id?: number;
    name: string;
}

export interface ScrumProject {
    id?: number;
    title: string;
    isprivate: boolean;
}


